//***********************************************
// USB Descriptor			            *
//***********************************************
//USB1.1 Descriptor
#define    GET_STATUS           0
#define    CLEAR_FEATURE        1
#define    SET_FEATURE          3
#define    SET_ADDRESS          5
#define    GET_DESCRIPTOR       6
#define    SET_DESCRIPTOR       7
#define    GET_CONFIGURATION    8
#define    SET_CONFIGURATION    9
#define    GET_INTERFACE        10
#define    SET_INTERFACE        11
#define    SYNCH_FRAME          12
#define    REQ_DONE             0xFF    //private code: request done

//Name of Descriptor
#define    DEVICE               1
#define    CONFIGURATION        2
#define    XSTRING              3
#define    INTERFACE            4
#define    ENDPOINT             5

#define    DEVICE_REMOTE_WAKEUP 1
#define    ENDPOINT_STALL       0
   
//Length of Descriptor
#define     DEV_LENGTH      18
#define     CFG_LENGTH      9
#define     INT_LENGTH      9
#define     HID_LENGTH      0
#define     END_LENGTH      7
#define     SIZE            DEV_LENGTH+CFG_LENGTH+INT_LENGTH+6*END_LENGTH
#define     CFG_DESC_SIZE   CFG_LENGTH+INT_LENGTH+6*END_LENGTH
#define     RPT_DESC_SIZE   0

///// Descriptor Offset
#define     DEV_DESC_OFS    0
#define     CFG_DESC_OFS    DEV_LENGTH
#define     IF_DESC_OFS     CFG_DESC_OFS + CFG_LENGTH
#define     HID_DESC_OFS    IF_DESC_OFS + INT_LENGTH
#define     EOP_DESC_OFS    HID_DESC_OFS + HID_LENGTH
#define     HIDREPORT_OFS   EOP_DESC_OFS + (END_LENGTH * 6)

//////////////  Define Descriptor  ///////////////////////

const  char DESC[]={

        DEV_LENGTH,     //length of this descriptor
        1,              //DEVICE descriptor
        0,              //spec rev level
        1,
        0,              //device class
        0,              //device subclass
        0,              //device protocol
        8,              //max packet size
        0xda,           //vendor ID
        8,
        0xa,           //product ID
        0xff,
        0,              //revision ID
        0,  
        1,              //index of manufacturing string
        2,              //index of product string
        0,              //index of serial Number string
        1,              //number of configs
             
//CFG_DESC
        CFG_LENGTH,     //length of this descriptor
        CONFIGURATION,  //CONFIGURATION descriptor
        CFG_DESC_SIZE,  //total length returned Hi
        0,              //total length returned Lo
        1,              //number of interfaces
        1,              //number of this config
        4,              //index of configuration string
        0xc0,           //self powered
        100,            //max power (200 mA)

//IF_DESC
        INT_LENGTH,      //length of this descriptor
        INTERFACE,      //INTERFACE descriptor
        0,              //interface number
        0,              //alternate setting
        6,              //Number of endpoints(0͏)
        0,              //interface class
        0,              //interface subclass
        0,              //interface protocol
        5,              //index of interface string

//HID_DESC

//EOP_DESC

//Pipe 0
        END_LENGTH,     //length of this descriptor
        ENDPOINT,       //ENDPOINT descriptor
        0x81,           //address (IN)
        2,              //attributes  (BULK)
        0x40,           //max packet size (64)
        0,
        0xFF,           //interval (ms)

//Pipe 1
        END_LENGTH,     //length of this descriptor
        ENDPOINT,       //ENDPOINT descriptor
        0x2,            //address (OUT)
        2,              //attributes  (BULK)
        0x40,           //max packet size (64)
        0,
        0xFF,           //interval (ms)

//Pipe 3
        END_LENGTH,     //length of this descriptor
        ENDPOINT,       //ENDPOINT descriptor
        0x83,           //address (IN)
        2,              //attributes  (BULK)
        0x40,           //max packet size (64)
        0,
        0xFF,           //interval (ms)

//Pipe 4
        END_LENGTH,     //length of this descriptor
        ENDPOINT,       //ENDPOINT descriptor
        0x4,            //address (OUT)
        2,              //attributes  (BULK)
        0x40,           //max packet size (64)
        0,
        0xFF,           //interval (ms)

//Pipe 5
        END_LENGTH,     //length of this descriptor
        ENDPOINT,       //ENDPOINT descriptor
        0x85,           //address (IN)
        2,              //attributes  (BULK)
        0x40,           //max packet size (64)
        0,
        0xFF,           //interval (ms)

//Pipe 6
        END_LENGTH,     //length of this descriptor
        ENDPOINT,       //ENDPOINT descriptor
        0x6,            //address (OUT)
        2,              //attributes  (BULK)
        0x40,           //max packet size (64)
        0,
        0xFF           //interval (ms)
};
//REPORT_DESC           //because of not HID, so not need

const char MFG_STR[] = "Kane Corp.";
const char PID_STR[] = "USBN9604 Basic";
const char NBR_STR[] = "V1.00";
const char CFG_STR[] = "Basic Config";
const char INT_STR[] = "6 pipe";
