//////////////////////////////////////////////////////////////
//
//   Define Registers of USBN960x
//
/////////////////////////////////////////////////////////////
#define        MCNTRL           0x0     //Main Control Register
#define        CCONF            0x1     //Clock Configuration Register
#define        reserved         0x2     //reserved
#define        RID              0x3     //Revision Identifier
#define        FAR              0x4     //Function Address Register
#define        NFSR             0x5     //Node Function Status Register
#define        MAEV             0x6     //Main Event Register
#define        MAMSK            0x7     //Main Mask Register
#define        ALTEV            0x8     //Alternate Event Register
#define        ALTMSK           0x9     //Alternate Mask Register
#define        TXEV             0xA     //Transmit Event Register
#define        TXMSK            0xB     //Transmit Mask Register
#define        RXEV             0xC     //Receive Event Register
#define        RXMSK            0xD     //Receive Mask Register
#define        NAKEV            0xE     //NAK Event Register
#define        NAKMSK           0xF     //NAk Mask Register
#define        FWEV             0x10    //FIFO Warning Event Register
#define        FWMSK            0x11    //FIFO warning Mask Register
#define        FNH              0x12    //Frame Number Register High Byte
#define        FNL              0x13    //Frame Number Register Low Byte
#define        DMACNTRL         0x14    //DMA Control Register

#define        EPC0             0x20    //Endpoint Control Register 0
#define        TXD0             0x21    //Transmit Data Register 0
#define        TXS0             0x22    //Transmit Status Register 0
#define        TXC0             0x23    //Transmit Command Register 0

#define        RXD0             0x25    //Receive Data Register 0
#define        RXS0             0x26    //Receive Status Register 0
#define        RXC0             0x27    //Receive Command Register 0
    
#define        EPC1             0x28    //Endpoint Control Register 1
#define        TXD1             0x29    //Transmit Data Register 1
#define        TXS1             0x2A    //Transmit Status Register 1
#define        TXC1             0x2B    //Transmit Command Register 1

#define        EPC2             0x2C    //Endpoint Control Register 2
#define        RXD1             0x2D    //Receive Data Register 1
#define        RXS1             0x2E    //Receive Status Register 1
#define        RXC1             0x2F    //Receive Command Register 1

#define        EPC3             0x30    //Endpoint Control Register 3
#define        TXD2             0x31    //Transmit Data Register 2
#define        TXS2             0x32    //Transmit Status Register 2
#define        TXC2             0x33    //Transmit Command Register 2

#define        EPC4             0x34    //Endpoint Control Register 4
#define        RXD2             0x35    //Receive Data Register 2
#define        RXS2             0x36    //Receive Status Register 2
#define        RXC2             0x37    //Receive Command Register 2

#define        EPC5             0x38    //Endpoint Control Register 5
#define        TXD3             0x39    //Transmit Data Register 3
#define        TXS3             0x3A    //Transmit Status Register 3
#define        TXC3             0x3B    //Transmit Command Register 3

#define        EPC6             0x3C    //Endpoint Control Register 6
#define        RXD3             0x3D    //Receive Data Register 3
#define        RXS3             0x3E    //Receive Status Register 3
#define        RXC3             0x3F    //Receive Command Register 3

//********* MCNTRL bits **********
#define        SRST             0x1     //Software Reset
#define        VGE              0x4     //Voltage Regulator Enable
#define        NAT              0x8     //Node Attached
#define        INT_DIS          0x0     //Disabled(active-high, open drain)
#define        INT_L_O          0x40    //active-low open drain
#define        INT_H_P          0x80    //active-higj push-pull
#define        INT_L_P          0xC0    //active-low push-pull

//********* FAR bits *************
#define        AD_EN            0x80    //Address Enable

//********* NFSR data ************
#define        RST_ST           0x0     //Node Reset
#define        RSM_ST           0x1     //Node Resume
#define        OPR_ST           0x2     //Node Operational
#define        SUS_ST           0x3     //Node Suspend

//****** MAEV, MAMSK bits  *******
#define        WARN             0x1     //FIFO Warning
#define        ALT              0x2     //Alternate Event
#define        TX_EV            0x4     //Transmit Event
#define        FRAME            0x8     //Frame Event
#define        NAK              0x10    //NAK Handshake
#define        ULD              0x20    //Unlock Locked Detected
#define        RX_EV            0x40    //Receive Event
#define        INTR_E           0x80    //Master Interrupt Enable


//****** ALTEV, ALTMSK bits  *****
#define        EOP              0x8     //End of Packet
#define        SD3              0x10    //Suspend Detect 3 ms
#define        SD5              0x20    //Suspend Detect 5 ms
#define        RESET_A          0x40    //Reset
#define        RESUME_A         0x80    //Resume

//******* TXEV, TXMSK bits  ******
#define        TXFIFO0          0x1     //Transmit FIFO 0
#define        TXFIFO1          0x2     //Transmit FIFO 1
#define        TXFIFO2          0x4     //Transmit FIFO 2
#define        TXFIFO3          0x8     //Transmit FIFO 3
#define        TXUDRN0          0x10    //Transmit Underrun 0
#define        TXUDRN1          0x20    //Transmit Underrun 1
#define        TXUDRN2          0x40    //Transmit Underrun 2
#define        TXUDRN3          0x80    //Transmit Underrun 3

//******* RXEV, RXMSK bits  ******
#define        RXFIFO0          0x1     //Receive FIFO 0
#define        RXFIFO1          0x2     //Receive FIFO 1
#define        RXFIFO2          0x4     //Receive FIFO 2
#define        RXFIFO3          0x8     //Receive FIFO 3
#define        RXOVRN0          0x10    //Receive Overrun 0
#define        RXOVRN1          0x20    //Receive Overrun 1
#define        RXOVRN2          0x40    //Receive Overrun 2
#define        RXOVRN3          0x80    //Receive Overrun 3

//******* NAKEV, NAKMSK bits  **********************
#define        NAK_I0           0x1     //In Token NAK 0
#define        NAK_I1           0x2     //In Token NAK 1
#define        NAK_I2           0x4     //In Token NAK 2
#define        NAK_I3           0x8     //In Token NAK 3
#define        NAK_O0           0x10    //Out Token NAK 0
#define        NAK_O1           0x20    //Out Token NAK 1
#define        NAK_O2           0x40    //Out Token NAK 2
#define        NAK_O3           0x80    //Out Token NAK 3

//********* EPCX bits ************
#define        EP_EN            0x10    //Endpoint Enable (1-6)
#define        ISO              0x20    //Isochronous Endpoint (1-6)
#define        DEF              0x40    //Default Address (0)
#define        STALL            0x80    //Stall Handshake (0-6)

//******** TXCx bits *************
#define        TX_EN            0x1     //Transmit Enable
#define        TX_LAST          0x2     //Last Byte
#define        TX_TOGL          0x4     //Data Toggle
#define        FLUSH            0x8     //Flush FIFO
#define		   IGN_IN			0x10	//Ignore in Tokens

//******** TXSx bits *************
#define        TX_DONE          0x20    //Transmit Done
#define        ACK_STAT         0x40    //Ackknowledge Status

//******** RXC0 bits *************
#define        IGN_OUT          0x2     //Ignore OUT Tokens
#define        IGN_SETUP        0x4     //Ignore SETUP Tokens

//******** RXCx bits *************
#define        RX_EN            0x1     //Receive enable

//******** RXS0 bits *************
#define        RX_LAST          0x10    //Receive Last
#define        RX_TOGL          0x20    //Data Toggle
#define        SETUP_RX         0x40    //Setup Packet
#define        RX_ERR           0x80    //Error

//***********************************************
//  9602 commands and constants                 *
//***********************************************
#define    USBREAD              0x00    //reads data
#define    USBWRITE             0x80    //write register
#define    USBBURST             0xC0    //burst write


////////  Constant Define ////////////
#define     NORMAL_ALTMSK   SD3+RESET_A
#define     SUSPND_ALTMSK   RESUME_A+RESET_A
#define     SUSPND_TO       4




